==> ToolChain_STM32_1.0.46.tar.bz: ToolChain_STM32_1.0.46/ToolChain/install_22_ExampleLCD.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="600_example_lcd"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="${INSTALLPATH}_printf"
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name
  
# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_$Name


INCLUDE_DIRS += -I additionals/examples/
vpath %.c additionals/examples/

MAIN_OBJS += example_lcd_320x240.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "Example of how to print on LCD-screen"
  cat <<END_OF_ACTIVATE >>$File #{

if [ "\$TEST" != "" ]; then # Testmode: activate board being required to successfully compile this example 
    activate.100_board_olimex_lcd.sh
fi
activate.500_ttc_gpio.sh QUIET \"\$0\"

# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $Name
  #}

  Name="${INSTALLPATH}_boxes"
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_$Name

INCLUDE_DIRS += -I additionals/examples/
vpath %.c additionals/examples/

MAIN_OBJS += example_lcd_boxes.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "Example of how to draw moving boxes with multiple tasks"
  cat <<END_OF_ACTIVATE >>$File #{

activate.500_ttc_gpio.sh QUIET \"\$0\"
activate.500_ttc_random.sh QUIET \"\$0\"

# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $Name
  #}

  echo "Installed successfully: $INSTALLPATH"

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.49.tar.bz: ToolChain_STM32_1.0.49/ToolChain/install_22_ExampleLCD.sh <==
#!/bin/bash

#
#  Install script for Fixpoint Mathematical Library 
#  URL: http://code.google.com/p/fixpointlib/
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="600_example_lcd"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

  Name="${INSTALLPATH}_printf"
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name
  
# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_$Name


INCLUDE_DIRS += -I examples/
vpath %.c examples/

MAIN_OBJS += example_lcd_320x240.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "Example of how to print on LCD-screen"
  cat <<END_OF_ACTIVATE >>$File #{

if [ "\$TEST" != "" ]; then # Testmode: activate board being required to successfully compile this example 
    activate.100_board_olimex_lcd.sh
fi
activate.500_ttc_gpio.sh QUIET \"\$0\"

# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $Name
  #}

  Name="${INSTALLPATH}_boxes"
  createExtensionMakefileHead ${Name} #{
  cat <<END_OF_MAKEFILE >>../extensions/makefile.$Name

# activate certain parts of source-code
COMPILE_OPTS += -DEXTENSION_$Name

INCLUDE_DIRS += -I examples/
vpath %.c examples/

MAIN_OBJS += example_lcd_boxes.o

END_OF_MAKEFILE
  createExtensionMakefileTail ${Name} #}
  File="../extensions/activate.${Name}.sh" #{
  createActivateScriptHead $File $0 "Example of how to draw moving boxes with multiple tasks"
  cat <<END_OF_ACTIVATE >>$File #{

activate.500_ttc_gpio.sh QUIET \"\$0\"
activate.500_ttc_random.sh QUIET \"\$0\"

# rm 2>/dev/null \$Dir_ExtensionsActive/makefile.600_example_*
createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET

END_OF_ACTIVATE
#}
  createActivateScriptTail $File $Name
  #}

  echo "Installed successfully: $INSTALLPATH"

cd ..
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
